@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11715 2019-09-18 14:34:08Z Lavender $
+# $Id: forms.py 11727 2019-09-25 19:02:22Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-09-18 23:34:08 +0900 (週三, 18 九月 2019) $
-# $Revision: 11715 $
+# $Date: 2019-09-26 04:02:22 +0900 (週四, 26 九月 2019) $
+# $Revision: 11727 $
 
 import os
 import hashlib
@@ -284,7 +284,7 @@ if VERSION >= (2, 0, 0):
                 self.fields['quantity'].widget = forms.HiddenInput()
     
     BasketMessageGenerator = get_class('basket.utils', 'BasketMessageGenerator')
-      
+    
     class BasketAddView(basketViews.BasketAddView):
     
         form_class = AddToBasketForm 
@@ -292,6 +292,7 @@ if VERSION >= (2, 0, 0):
         def form_valid(self, form): 
             # save file
             options = form.cleaned_options()
+            
             for optionData in options:
                 option = optionData['option']
                 ot, created = OptionType.objects.get_or_create(
@@ -302,24 +303,30 @@ if VERSION >= (2, 0, 0):
                     }
                 )
                 if ot.type in [FILE, IMAGE]:
-                    f = self.request.FILES.get(option.code)
-                    pathId = hashlib.md5(
-                        ("%s" % (
-                            datetime.datetime.now(),
-                        )).encode()).hexdigest()
-                    mediaPath = os.path.join('OptionUpload', pathId, str(f))
-                    uploadPath = os.path.join(settings.MEDIA_ROOT, mediaPath)
-                    if os.path.exists(uploadPath):
-                        os.remove(uploadPath)
+                    f = self.request.FILES.get(option.code, None)
+                    if f:
+                        pathId = hashlib.md5(
+                            ("%s%s" % (
+                                str(f),
+                                datetime.datetime.now(),
+                            )).encode()).hexdigest()
+                        mediaPath = os.path.join(
+                            'OptionUpload', pathId, str(f))
+                        uploadPath = os.path.join(
+                            settings.MEDIA_ROOT, mediaPath)
+                        if os.path.exists(uploadPath):
+                            os.remove(uploadPath)
+                        
+                        path = default_storage.save(
+                            mediaPath, 
+                            ContentFile(f.read())
+                        )
+                        
+                        optionData['value'] = mediaPath
+                    else:
+                        optionData['value'] = ''
                     
-                    path = default_storage.save(
-                        mediaPath, 
-                        ContentFile(f.read())
-                    )
-                    
-                    optionData['value'] = mediaPath
-                    
-            # 以下複製的，因為會造成循環 super 的問題
+            # 以下複製的，因為要修改其中一段
             offers_before = self.request.basket.applied_offers()
 
             line, created = self.request.basket.add_product(
